# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AgentChatDynamicToolState(Enum):
    INPUT_STREAMING = "input-streaming"
    INPUT_AVAILABLE = "input-available"
    OUTPUT_AVAILABLE = "output-available"
    OUTPUT_ERROR = "output-error"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AgentChatAttachment(object):
    @poscheck_model
    def __init__(self,
                 kind=None,
                 tool_call_id=None,
                 attributes=None):
        # type: (string_types, string_types, dict) -> None

        self._kind = None
        self._tool_call_id = None
        self._attributes = None
        self.discriminator = None

        if kind is not None:
            self.kind = kind
        if tool_call_id is not None:
            self.tool_call_id = tool_call_id
        if attributes is not None:
            self.attributes = attributes

    @property
    def openapi_types(self):
        types = {
            'kind': 'string_types',
            'tool_call_id': 'string_types',
            'attributes': 'dict(str, object)'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'kind': 'kind',
            'tool_call_id': 'toolCallId',
            'attributes': 'attributes'
        }
        return attributes

    @property
    def kind(self):
        # type: () -> string_types
        """Gets the kind of this AgentChatAttachment.

        Attachment kind (required)

        :return: The kind of this AgentChatAttachment.
        :rtype: string_types
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        # type: (string_types) -> None
        """Sets the kind of this AgentChatAttachment.

        Attachment kind (required)

        :param kind: The kind of this AgentChatAttachment.
        :type: string_types
        """

        if kind is not None:
            if not isinstance(kind, string_types):
                raise TypeError("Invalid type for `kind`, type has to be `string_types`")

        self._kind = kind

    @property
    def tool_call_id(self):
        # type: () -> string_types
        """Gets the tool_call_id of this AgentChatAttachment.

        Tool call identifier

        :return: The tool_call_id of this AgentChatAttachment.
        :rtype: string_types
        """
        return self._tool_call_id

    @tool_call_id.setter
    def tool_call_id(self, tool_call_id):
        # type: (string_types) -> None
        """Sets the tool_call_id of this AgentChatAttachment.

        Tool call identifier

        :param tool_call_id: The tool_call_id of this AgentChatAttachment.
        :type: string_types
        """

        if tool_call_id is not None:
            if not isinstance(tool_call_id, string_types):
                raise TypeError("Invalid type for `tool_call_id`, type has to be `string_types`")

        self._tool_call_id = tool_call_id

    @property
    def attributes(self):
        # type: () -> dict(str, object)
        """Gets the attributes of this AgentChatAttachment.

        Attachment attributes map (required)

        :return: The attributes of this AgentChatAttachment.
        :rtype: dict(str, object)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        # type: (dict) -> None
        """Sets the attributes of this AgentChatAttachment.

        Attachment attributes map (required)

        :param attributes: The attributes of this AgentChatAttachment.
        :type: dict(str, object)
        """

        if attributes is not None:
            if not isinstance(attributes, dict):
                raise TypeError("Invalid type for `attributes`, type has to be `dict(str, object)`")

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentChatAttachment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class S3StorageClass(Enum):
    GLACIER_IR = "GLACIER_IR"
    INTELLIGENT_TIERING = "INTELLIGENT_TIERING"
    ONEZONE_IA = "ONEZONE_IA"
    REDUCED_REDUNDANCY = "REDUCED_REDUNDANCY"
    STANDARD = "STANDARD"
    STANDARD_IA = "STANDARD_IA"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ai_scene_analysis_automatic_ad_placement import AiSceneAnalysisAutomaticAdPlacement
import pprint
import six


class SceneAnalysisAdPlacementMetadataResponse(object):
    @poscheck_model
    def __init__(self,
                 placed_ads=None,
                 automatic_ad_placement=None):
        # type: (list[AdPosition], AiSceneAnalysisAutomaticAdPlacement) -> None

        self._placed_ads = list()
        self._automatic_ad_placement = None
        self.discriminator = None

        if placed_ads is not None:
            self.placed_ads = placed_ads
        if automatic_ad_placement is not None:
            self.automatic_ad_placement = automatic_ad_placement

    @property
    def openapi_types(self):
        types = {
            'placed_ads': 'list[AdPosition]',
            'automatic_ad_placement': 'AiSceneAnalysisAutomaticAdPlacement'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'placed_ads': 'placedAds',
            'automatic_ad_placement': 'automaticAdPlacement'
        }
        return attributes

    @property
    def placed_ads(self):
        # type: () -> list[AdPosition]
        """Gets the placed_ads of this SceneAnalysisAdPlacementMetadataResponse.


        :return: The placed_ads of this SceneAnalysisAdPlacementMetadataResponse.
        :rtype: list[AdPosition]
        """
        return self._placed_ads

    @placed_ads.setter
    def placed_ads(self, placed_ads):
        # type: (list) -> None
        """Sets the placed_ads of this SceneAnalysisAdPlacementMetadataResponse.


        :param placed_ads: The placed_ads of this SceneAnalysisAdPlacementMetadataResponse.
        :type: list[AdPosition]
        """

        if placed_ads is not None:
            if not isinstance(placed_ads, list):
                raise TypeError("Invalid type for `placed_ads`, type has to be `list[AdPosition]`")

        self._placed_ads = placed_ads

    @property
    def automatic_ad_placement(self):
        # type: () -> AiSceneAnalysisAutomaticAdPlacement
        """Gets the automatic_ad_placement of this SceneAnalysisAdPlacementMetadataResponse.


        :return: The automatic_ad_placement of this SceneAnalysisAdPlacementMetadataResponse.
        :rtype: AiSceneAnalysisAutomaticAdPlacement
        """
        return self._automatic_ad_placement

    @automatic_ad_placement.setter
    def automatic_ad_placement(self, automatic_ad_placement):
        # type: (AiSceneAnalysisAutomaticAdPlacement) -> None
        """Sets the automatic_ad_placement of this SceneAnalysisAdPlacementMetadataResponse.


        :param automatic_ad_placement: The automatic_ad_placement of this SceneAnalysisAdPlacementMetadataResponse.
        :type: AiSceneAnalysisAutomaticAdPlacement
        """

        if automatic_ad_placement is not None:
            if not isinstance(automatic_ad_placement, AiSceneAnalysisAutomaticAdPlacement):
                raise TypeError("Invalid type for `automatic_ad_placement`, type has to be `AiSceneAnalysisAutomaticAdPlacement`")

        self._automatic_ad_placement = automatic_ad_placement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SceneAnalysisAdPlacementMetadataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AgentChatMessage(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 role=None,
                 parts=None):
        # type: (string_types, string_types, list[AgentChatMessagePart]) -> None

        self._id = None
        self._role = None
        self._parts = list()
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if role is not None:
            self.role = role
        if parts is not None:
            self.parts = parts

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'role': 'string_types',
            'parts': 'list[AgentChatMessagePart]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'role': 'role',
            'parts': 'parts'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this AgentChatMessage.

        Message ID (required)

        :return: The id of this AgentChatMessage.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this AgentChatMessage.

        Message ID (required)

        :param id_: The id of this AgentChatMessage.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def role(self):
        # type: () -> string_types
        """Gets the role of this AgentChatMessage.

        Message role (required)

        :return: The role of this AgentChatMessage.
        :rtype: string_types
        """
        return self._role

    @role.setter
    def role(self, role):
        # type: (string_types) -> None
        """Sets the role of this AgentChatMessage.

        Message role (required)

        :param role: The role of this AgentChatMessage.
        :type: string_types
        """

        if role is not None:
            if not isinstance(role, string_types):
                raise TypeError("Invalid type for `role`, type has to be `string_types`")

        self._role = role

    @property
    def parts(self):
        # type: () -> list[AgentChatMessagePart]
        """Gets the parts of this AgentChatMessage.

        Message parts (required)

        :return: The parts of this AgentChatMessage.
        :rtype: list[AgentChatMessagePart]
        """
        return self._parts

    @parts.setter
    def parts(self, parts):
        # type: (list) -> None
        """Sets the parts of this AgentChatMessage.

        Message parts (required)

        :param parts: The parts of this AgentChatMessage.
        :type: list[AgentChatMessagePart]
        """

        if parts is not None:
            if not isinstance(parts, list):
                raise TypeError("Invalid type for `parts`, type has to be `list[AgentChatMessagePart]`")

        self._parts = parts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentChatMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AgentSessionResponse(object):
    @poscheck_model
    def __init__(self,
                 session_id=None,
                 app_name=None,
                 user_id=None):
        # type: (string_types, string_types, string_types) -> None

        self._session_id = None
        self._app_name = None
        self._user_id = None
        self.discriminator = None

        if session_id is not None:
            self.session_id = session_id
        if app_name is not None:
            self.app_name = app_name
        if user_id is not None:
            self.user_id = user_id

    @property
    def openapi_types(self):
        types = {
            'session_id': 'string_types',
            'app_name': 'string_types',
            'user_id': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'session_id': 'sessionId',
            'app_name': 'appName',
            'user_id': 'userId'
        }
        return attributes

    @property
    def session_id(self):
        # type: () -> string_types
        """Gets the session_id of this AgentSessionResponse.

        Session ID (required)

        :return: The session_id of this AgentSessionResponse.
        :rtype: string_types
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        # type: (string_types) -> None
        """Sets the session_id of this AgentSessionResponse.

        Session ID (required)

        :param session_id: The session_id of this AgentSessionResponse.
        :type: string_types
        """

        if session_id is not None:
            if not isinstance(session_id, string_types):
                raise TypeError("Invalid type for `session_id`, type has to be `string_types`")

        self._session_id = session_id

    @property
    def app_name(self):
        # type: () -> string_types
        """Gets the app_name of this AgentSessionResponse.

        Agent application name (required)

        :return: The app_name of this AgentSessionResponse.
        :rtype: string_types
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        # type: (string_types) -> None
        """Sets the app_name of this AgentSessionResponse.

        Agent application name (required)

        :param app_name: The app_name of this AgentSessionResponse.
        :type: string_types
        """

        if app_name is not None:
            if not isinstance(app_name, string_types):
                raise TypeError("Invalid type for `app_name`, type has to be `string_types`")

        self._app_name = app_name

    @property
    def user_id(self):
        # type: () -> string_types
        """Gets the user_id of this AgentSessionResponse.

        User ID (required)

        :return: The user_id of this AgentSessionResponse.
        :rtype: string_types
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        # type: (string_types) -> None
        """Sets the user_id of this AgentSessionResponse.

        User ID (required)

        :param user_id: The user_id of this AgentSessionResponse.
        :type: string_types
        """

        if user_id is not None:
            if not isinstance(user_id, string_types):
                raise TypeError("Invalid type for `user_id`, type has to be `string_types`")

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentSessionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.agent_session_history_response import AgentSessionHistoryResponse
from bitmovin_api_sdk.models.agent_session_list_response import AgentSessionListResponse
from bitmovin_api_sdk.models.agent_session_response import AgentSessionResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class SessionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SessionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, **kwargs):
        # type: (dict) -> AgentSessionResponse
        """Create Agent Session

        :return: Created agent session
        :rtype: AgentSessionResponse
        """

        return self.api_client.post(
            '/agents/aisa/sessions',
            type=AgentSessionResponse,
            **kwargs
        )

    def delete(self, session_id, **kwargs):
        # type: (string_types, dict) -> AgentSessionResponse
        """Delete Agent Session

        :param session_id: Id of the session
        :type session_id: string_types, required
        :return: Deleted agent session
        :rtype: AgentSessionResponse
        """

        return self.api_client.delete(
            '/agents/aisa/sessions/{session_id}',
            path_params={'session_id': session_id},
            type=AgentSessionResponse,
            **kwargs
        )

    def get(self, session_id, **kwargs):
        # type: (string_types, dict) -> AgentSessionHistoryResponse
        """Get Agent Session Details

        :param session_id: Id of the session
        :type session_id: string_types, required
        :return: Agent session history
        :rtype: AgentSessionHistoryResponse
        """

        return self.api_client.get(
            '/agents/aisa/sessions/{session_id}',
            path_params={'session_id': session_id},
            type=AgentSessionHistoryResponse,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> AgentSessionListResponse
        """List Agent Sessions

        :return: Agent sessions list
        :rtype: AgentSessionListResponse
        """

        return self.api_client.get(
            '/agents/aisa/sessions',
            type=AgentSessionListResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.update_encoding_rtmp_ingest_point_request import UpdateEncodingRtmpIngestPointRequest
from bitmovin_api_sdk.models.update_encoding_rtmp_ingest_point_response import UpdateEncodingRtmpIngestPointResponse


class ActionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ActionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def patch(self, encoding_id, update_encoding_rtmp_ingest_point_request, **kwargs):
        # type: (string_types, UpdateEncodingRtmpIngestPointRequest, dict) -> UpdateEncodingRtmpIngestPointResponse
        """Update the ingest points of a Redundant RTMP Input

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param update_encoding_rtmp_ingest_point_request: The list of the RTMP ingest points to update.
        :type update_encoding_rtmp_ingest_point_request: UpdateEncodingRtmpIngestPointRequest, required
        :return:
        :rtype: UpdateEncodingRtmpIngestPointResponse
        """

        return self.api_client.patch(
            '/encoding/live/encodings/{encoding_id}/actions/update-rtmp-ingest-points',
            update_encoding_rtmp_ingest_point_request,
            path_params={'encoding_id': encoding_id},
            type=UpdateEncodingRtmpIngestPointResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.agent_chat_dynamic_tool_state import AgentChatDynamicToolState
from bitmovin_api_sdk.models.agent_chat_message_part import AgentChatMessagePart
import pprint
import six


class AgentChatDynamicToolPart(AgentChatMessagePart):
    @poscheck_model
    def __init__(self,
                 tool_name=None,
                 tool_call_id=None,
                 state=None,
                 input_=None,
                 output=None,
                 error_text=None):
        # type: (string_types, string_types, AgentChatDynamicToolState, dict, dict, string_types) -> None
        super(AgentChatDynamicToolPart, self).__init__()

        self._tool_name = None
        self._tool_call_id = None
        self._state = None
        self._input = None
        self._output = None
        self._error_text = None
        self.discriminator = None

        if tool_name is not None:
            self.tool_name = tool_name
        if tool_call_id is not None:
            self.tool_call_id = tool_call_id
        if state is not None:
            self.state = state
        if input_ is not None:
            self.input = input_
        if output is not None:
            self.output = output
        if error_text is not None:
            self.error_text = error_text

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AgentChatDynamicToolPart, self), 'openapi_types'):
            types = getattr(super(AgentChatDynamicToolPart, self), 'openapi_types')

        types.update({
            'tool_name': 'string_types',
            'tool_call_id': 'string_types',
            'state': 'AgentChatDynamicToolState',
            'input': 'dict(str, object)',
            'output': 'dict(str, object)',
            'error_text': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AgentChatDynamicToolPart, self), 'attribute_map'):
            attributes = getattr(super(AgentChatDynamicToolPart, self), 'attribute_map')

        attributes.update({
            'tool_name': 'toolName',
            'tool_call_id': 'toolCallId',
            'state': 'state',
            'input': 'input',
            'output': 'output',
            'error_text': 'errorText'
        })
        return attributes

    @property
    def tool_name(self):
        # type: () -> string_types
        """Gets the tool_name of this AgentChatDynamicToolPart.

        Tool name (required)

        :return: The tool_name of this AgentChatDynamicToolPart.
        :rtype: string_types
        """
        return self._tool_name

    @tool_name.setter
    def tool_name(self, tool_name):
        # type: (string_types) -> None
        """Sets the tool_name of this AgentChatDynamicToolPart.

        Tool name (required)

        :param tool_name: The tool_name of this AgentChatDynamicToolPart.
        :type: string_types
        """

        if tool_name is not None:
            if not isinstance(tool_name, string_types):
                raise TypeError("Invalid type for `tool_name`, type has to be `string_types`")

        self._tool_name = tool_name

    @property
    def tool_call_id(self):
        # type: () -> string_types
        """Gets the tool_call_id of this AgentChatDynamicToolPart.

        Tool call identifier (required)

        :return: The tool_call_id of this AgentChatDynamicToolPart.
        :rtype: string_types
        """
        return self._tool_call_id

    @tool_call_id.setter
    def tool_call_id(self, tool_call_id):
        # type: (string_types) -> None
        """Sets the tool_call_id of this AgentChatDynamicToolPart.

        Tool call identifier (required)

        :param tool_call_id: The tool_call_id of this AgentChatDynamicToolPart.
        :type: string_types
        """

        if tool_call_id is not None:
            if not isinstance(tool_call_id, string_types):
                raise TypeError("Invalid type for `tool_call_id`, type has to be `string_types`")

        self._tool_call_id = tool_call_id

    @property
    def state(self):
        # type: () -> AgentChatDynamicToolState
        """Gets the state of this AgentChatDynamicToolPart.

        Tool invocation lifecycle state (required)

        :return: The state of this AgentChatDynamicToolPart.
        :rtype: AgentChatDynamicToolState
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: (AgentChatDynamicToolState) -> None
        """Sets the state of this AgentChatDynamicToolPart.

        Tool invocation lifecycle state (required)

        :param state: The state of this AgentChatDynamicToolPart.
        :type: AgentChatDynamicToolState
        """

        if state is not None:
            if not isinstance(state, AgentChatDynamicToolState):
                raise TypeError("Invalid type for `state`, type has to be `AgentChatDynamicToolState`")

        self._state = state

    @property
    def input(self):
        # type: () -> dict(str, object)
        """Gets the input of this AgentChatDynamicToolPart.

        Tool input payload.

        :return: The input of this AgentChatDynamicToolPart.
        :rtype: dict(str, object)
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (dict) -> None
        """Sets the input of this AgentChatDynamicToolPart.

        Tool input payload.

        :param input_: The input of this AgentChatDynamicToolPart.
        :type: dict(str, object)
        """

        if input_ is not None:
            if not isinstance(input_, dict):
                raise TypeError("Invalid type for `input`, type has to be `dict(str, object)`")

        self._input = input_

    @property
    def output(self):
        # type: () -> dict(str, object)
        """Gets the output of this AgentChatDynamicToolPart.

        Tool output payload.

        :return: The output of this AgentChatDynamicToolPart.
        :rtype: dict(str, object)
        """
        return self._output

    @output.setter
    def output(self, output):
        # type: (dict) -> None
        """Sets the output of this AgentChatDynamicToolPart.

        Tool output payload.

        :param output: The output of this AgentChatDynamicToolPart.
        :type: dict(str, object)
        """

        if output is not None:
            if not isinstance(output, dict):
                raise TypeError("Invalid type for `output`, type has to be `dict(str, object)`")

        self._output = output

    @property
    def error_text(self):
        # type: () -> string_types
        """Gets the error_text of this AgentChatDynamicToolPart.

        Error text for failed tool completion.

        :return: The error_text of this AgentChatDynamicToolPart.
        :rtype: string_types
        """
        return self._error_text

    @error_text.setter
    def error_text(self, error_text):
        # type: (string_types) -> None
        """Sets the error_text of this AgentChatDynamicToolPart.

        Error text for failed tool completion.

        :param error_text: The error_text of this AgentChatDynamicToolPart.
        :type: string_types
        """

        if error_text is not None:
            if not isinstance(error_text, string_types):
                raise TypeError("Invalid type for `error_text`, type has to be `string_types`")

        self._error_text = error_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AgentChatDynamicToolPart, self), "to_dict"):
            result = super(AgentChatDynamicToolPart, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentChatDynamicToolPart):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ad_markers_source import AdMarkersSource
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class HlsInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 url=None,
                 ad_markers_source=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, AdMarkersSource) -> None
        super(HlsInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._url = None
        self._ad_markers_source = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if ad_markers_source is not None:
            self.ad_markers_source = ad_markers_source

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(HlsInput, self), 'openapi_types'):
            types = getattr(super(HlsInput, self), 'openapi_types')

        types.update({
            'url': 'string_types',
            'ad_markers_source': 'AdMarkersSource'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(HlsInput, self), 'attribute_map'):
            attributes = getattr(super(HlsInput, self), 'attribute_map')

        attributes.update({
            'url': 'url',
            'ad_markers_source': 'adMarkersSource'
        })
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this HlsInput.

        URL of HLS input

        :return: The url of this HlsInput.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this HlsInput.

        URL of HLS input

        :param url: The url of this HlsInput.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def ad_markers_source(self):
        # type: () -> AdMarkersSource
        """Gets the ad_markers_source of this HlsInput.

        Specifies the source for ad markers messages: - MANIFEST: Ad marker messages are read from tags in the HLS manifest - SEGMENTS: Ad marker messages are read from the content segments from the data stream 

        :return: The ad_markers_source of this HlsInput.
        :rtype: AdMarkersSource
        """
        return self._ad_markers_source

    @ad_markers_source.setter
    def ad_markers_source(self, ad_markers_source):
        # type: (AdMarkersSource) -> None
        """Sets the ad_markers_source of this HlsInput.

        Specifies the source for ad markers messages: - MANIFEST: Ad marker messages are read from tags in the HLS manifest - SEGMENTS: Ad marker messages are read from the content segments from the data stream 

        :param ad_markers_source: The ad_markers_source of this HlsInput.
        :type: AdMarkersSource
        """

        if ad_markers_source is not None:
            if not isinstance(ad_markers_source, AdMarkersSource):
                raise TypeError("Invalid type for `ad_markers_source`, type has to be `AdMarkersSource`")

        self._ad_markers_source = ad_markers_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(HlsInput, self), "to_dict"):
            result = super(HlsInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HlsInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AgentChatMessagePartType(Enum):
    TEXT = "text"
    DATA_ATTACHMENTS = "data-attachments"
    DYNAMIC_TOOL = "dynamic-tool"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AllSceneBoundaries(object):
    @poscheck_model
    def __init__(self,
                 is_enabled=None,
                 insert_cue_tags=None):
        # type: (bool, bool) -> None

        self._is_enabled = None
        self._insert_cue_tags = None
        self.discriminator = None

        if is_enabled is not None:
            self.is_enabled = is_enabled
        if insert_cue_tags is not None:
            self.insert_cue_tags = insert_cue_tags

    @property
    def openapi_types(self):
        types = {
            'is_enabled': 'bool',
            'insert_cue_tags': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'is_enabled': 'isEnabled',
            'insert_cue_tags': 'insertCueTags'
        }
        return attributes

    @property
    def is_enabled(self):
        # type: () -> bool
        """Gets the is_enabled of this AllSceneBoundaries.

        If true, a keyframe (IDR frame) is placed at every detected scene boundary, enabling clean segment cuts aligned with scene changes. 

        :return: The is_enabled of this AllSceneBoundaries.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        # type: (bool) -> None
        """Sets the is_enabled of this AllSceneBoundaries.

        If true, a keyframe (IDR frame) is placed at every detected scene boundary, enabling clean segment cuts aligned with scene changes. 

        :param is_enabled: The is_enabled of this AllSceneBoundaries.
        :type: bool
        """

        if is_enabled is not None:
            if not isinstance(is_enabled, bool):
                raise TypeError("Invalid type for `is_enabled`, type has to be `bool`")

        self._is_enabled = is_enabled

    @property
    def insert_cue_tags(self):
        # type: () -> bool
        """Gets the insert_cue_tags of this AllSceneBoundaries.

        If true, cue tags are inserted at every scene boundary in addition to keyframes. 

        :return: The insert_cue_tags of this AllSceneBoundaries.
        :rtype: bool
        """
        return self._insert_cue_tags

    @insert_cue_tags.setter
    def insert_cue_tags(self, insert_cue_tags):
        # type: (bool) -> None
        """Sets the insert_cue_tags of this AllSceneBoundaries.

        If true, cue tags are inserted at every scene boundary in addition to keyframes. 

        :param insert_cue_tags: The insert_cue_tags of this AllSceneBoundaries.
        :type: bool
        """

        if insert_cue_tags is not None:
            if not isinstance(insert_cue_tags, bool):
                raise TypeError("Invalid type for `insert_cue_tags`, type has to be `bool`")

        self._insert_cue_tags = insert_cue_tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AllSceneBoundaries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
